/*
  Copyright 2019 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.model

import android.os.Parcelable
import com.google.gson.annotations.SerializedName
import kotlinx.android.parcel.Parcelize

/**
 * 메시지 전송 API 호출 결과
 *
 * @author kevin.kang. Created on 2019-10-16..
 * @since 2.0.0
 *
 */
@Parcelize
data class PartnerMessageSendResult(val successfulReceiverIds: List<String>?, @SerializedName("failure_info") val failureInfos: List<PartnerMessageFailureInfo>?) :
    Parcelable

/**
 * 복수의 친구를 대상으로 메시지 전송 API 호출 시 대상 중 일부가 실패한 경우 오류 정보를 제공합니다.
 */
@Parcelize
data class PartnerMessageFailureInfo(
    val code: Int,
    val msg: String,
    val receiverIds: List<String>
) : Parcelable