/*
  Copyright 2019 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner

import com.kakao.sdk.template.DefaultTemplate
import com.kakao.sdk.partner.model.*
import com.kakao.sdk.talk.Constants
import com.kakao.sdk.talk.model.Friends
import com.kakao.sdk.talk.model.Order
import io.reactivex.Completable
import com.kakao.sdk.partner.Constants as PartnerConstants
import io.reactivex.Single
import retrofit2.http.*

/**
 * @suppress
 * @author kevin.kang. Created on 08/04/2019..
 */
interface RxPartnerApi {
    @GET(com.kakao.sdk.user.Constants.V2_ME_PATH)
    fun me(
        @Query(com.kakao.sdk.user.Constants.PROPERTYKEYS) properties: String? = null,
        @Query(com.kakao.sdk.user.Constants.SECURE_RESOURCE) secureResource: Boolean = true
    ): Single<PartnerUser>

    @POST(PartnerConstants.V1_SIGNUP_PATH)
    @FormUrlEncoded
    fun signup(
        @Field(com.kakao.sdk.user.Constants.PROPERTIES) properties: Map<String, String>? = null
    ): Completable

    @GET(PartnerConstants.V1_FRIENDS_PATH)
    fun friends(
        @Query(PartnerConstants.FRIEND_TYPE) friendType: FriendType? = null,
        @Query(PartnerConstants.FRIEND_FILTER) friendFilter: FriendFilter? = null,
        @Query(Constants.FRIEND_ORDER) friendOrder: FriendOrder? = null,
        @Query(Constants.OFFSET) offset: Int? = null,
        @Query(Constants.LIMIT) limit: Int? = null,
        @Query(Constants.ORDER) order: Order? = null,
        @Query(com.kakao.sdk.auth.Constants.SECURE_RESOURCE) secureResource: Boolean? = true
    ): Single<Friends<PartnerFriend>>

    @GET(PartnerConstants.V1_CHATS_PATH)
    fun chatList(
        @Query(PartnerConstants.FILTER) filter: String? = null,
        @Query(PartnerConstants.OFFSET) offset: Int? = null,
        @Query(Constants.LIMIT) limit: Int? = null,
        @Query(Constants.ORDER) order: Order? = null,
        @Query(Constants.SECURE_RESOURCE) secureResource: Boolean? = true
    ): Single<Chats>

    @GET(PartnerConstants.V1_CHAT_MEMBERS_PATH)
    fun chatMembers(
        @Query(PartnerConstants.CHAT_ID) chatId: Long,
        @Query(PartnerConstants.FRIENDS_ONLY) friendsOnly: Boolean? = null,
        @Query(PartnerConstants.INCLUDE_PROFILE) includeProfile: Boolean? = null,
        @Query(Constants.OFFSET) offset: Int? = null,
        @Query(Constants.LIMIT) limit: Int? = null,
        @Query(Constants.ORDER) order: Order? = null,
        @Query(Constants.SECURE_RESOURCE) secureResource: Boolean? = true
    ): Single<ChatMembers>

    @FormUrlEncoded
    @POST(PartnerConstants.V2_MESSAGE_PATH)
    fun sendMessage(
        @Field(PartnerConstants.RECEIVER_ID_TYPE) receiverIdType: String? = null,
        @Field(PartnerConstants.RECEIVER_IDS) receiverIds: String,
        @Field(Constants.TEMPLATE_ID) templateId: Long,
        @Field(Constants.TEMPLATE_ARGS) templateArgs: Map<String, String>? = null
    ): Single<PartnerMessageSendResult>

    @FormUrlEncoded
    @POST(PartnerConstants.V2_MESSAGE_DEFAULT_PATH)
    fun sendMessage(
        @Field(PartnerConstants.RECEIVER_ID_TYPE) receiverIdType: String? = null,
        @Field(PartnerConstants.RECEIVER_IDS) receiverIds: String,
        @Field(Constants.TEMPLATE_OBJECT) templateParams: DefaultTemplate
    ): Single<PartnerMessageSendResult>

    @FormUrlEncoded
    @POST(PartnerConstants.V2_MESSAGE_SCRAP_PATH)
    fun sendMessage(
        @Field(PartnerConstants.RECEIVER_ID_TYPE) receiverIdType: String? = null,
        @Field(PartnerConstants.RECEIVER_IDS) receiverIds: String,
        @Field(Constants.REQUEST_URL) requestUrl: String,
        @Field(Constants.TEMPLATE_ID) templateId: Long? = null,
        @Field(Constants.TEMPLATE_ARGS) templateArgs: Map<String, String>? = null
    ): Single<PartnerMessageSendResult>
}